@@ -40,6 +40,7 @@ from googlecloudsdk.core import exceptions as core_exc
 from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
 from googlecloudsdk.core.credentials import transports
+from googlecloudsdk.core.util import scaled_integer
 
 import six
 
@@ -60,6 +61,16 @@ class UploadError(Error):
   """Error raised when there are problems uploading files."""
 
 
+class BucketInWrongProjectError(Error):
+  """Error raised when a bucket exists in a project the user doesn't own.
+
+  Specifically, this applies when a command creates a bucket if it doesn't
+  exist, or returns the existing bucket otherwise. If the bucket exists but is
+  owned by a different project, it could belong to a malicious user squatting on
+  the bucket name.
+  """
+
+
 def _GetMimetype(local_path):
   mime_type, _ = mimetypes.guess_type(local_path)
   return mime_type or 'application/octet-stream'
@@ -87,7 +98,8 @@ class StorageClient(object):
     the property defined chunk size to the nearest chunk size interval.
     """
     gcs_chunk_granularity = 256 * 1024  # 256 KiB
-    chunksize = properties.VALUES.storage.chunk_size.GetInt()
+    chunksize = scaled_integer.ParseInteger(
+        properties.VALUES.storage.upload_chunk_size.Get())
     if chunksize == 0:
       chunksize = None  # Use apitools default (1048576 B)
     elif chunksize % gcs_chunk_granularity != 0:
@@ -330,20 +342,44 @@ class StorageClient(object):
       # Bucket doesn't exist, we'll try to create it.
       raise BucketNotFoundError('Bucket [{}] does not exist.'.format(bucket))
 
-  def CreateBucketIfNotExists(self, bucket, project=None, location=None):
+  def CreateBucketIfNotExists(
+      self,
+      bucket,
+      project=None,
+      location=None,
+      check_ownership=True,
+      enable_uniform_level_access=None,
+      soft_delete_duration=None,
+      cors=None,
+  ):
     """Create a bucket if it does not already exist.
 
-    If it already exists and is owned by the creator, no problem.
+    If it already exists and is accessible by the current user, this method
+    returns.
 
     Args:
       bucket: str, The storage bucket to be created.
       project: str, The project to use for the API request. If None, current
-          Cloud SDK project is used.
+        Cloud SDK project is used.
       location: str, The bucket location/region.
+      check_ownership: bool, Whether to check that the resulting bucket belongs
+        to the given project. DO NOT SET THIS TO FALSE if the bucket name can be
+        guessed and claimed ahead of time by another user as it enables a name
+        squatting exploit.
+      enable_uniform_level_access: bool, to enable uniform bucket level access.
+        If None, the iamConfiguration object will not be created in the bucket
+        creation request, which means that it will use the default values.
+      soft_delete_duration: int, the soft delete duration in seconds.
+      cors: list, A list of CorsValueListEntry objects. The bucket's
+        Cross-Origin Resource Sharing (CORS) configuration. If None, no CORS
+        configuration will be set.
 
     Raises:
-      api_exceptions.HttpError: If the bucket is owned by someone else
-          or is otherwise not able to be created.
+      api_exceptions.HttpError: If the bucket is not able to be created or is
+        not accessible due to permissions.
+      BucketInWrongProjectError: If the bucket already exists in a different
+        project. This could belong to a malicious user squatting on the bucket
+        name.
     """
     project = project or properties.VALUES.core.project.Get(required=True)
 
@@ -359,14 +395,27 @@ class StorageClient(object):
       ))
     except api_exceptions.HttpNotFoundError:
       # Bucket doesn't exist, we'll try to create it.
+      storage_buckets_insert_request = (
+          self.messages.StorageBucketsInsertRequest(
+              project=project,
+              bucket=self.messages.Bucket(name=bucket,
+                                          location=location)))
+      if enable_uniform_level_access is not None:
+        storage_buckets_insert_request.bucket.iamConfiguration = (
+            self.messages.Bucket.IamConfigurationValue(
+                uniformBucketLevelAccess=(
+                    self.messages.Bucket.IamConfigurationValue.UniformBucketLevelAccessValue(
+                        enabled=enable_uniform_level_access))))
+      if cors is not None:
+        storage_buckets_insert_request.bucket.cors = cors
+      if soft_delete_duration is not None:
+        storage_buckets_insert_request.bucket.softDeletePolicy = (
+            self.messages.Bucket.SoftDeletePolicyValue(
+                retentionDurationSeconds=soft_delete_duration
+            )
+        )
       try:
-        self.client.buckets.Insert(
-            self.messages.StorageBucketsInsertRequest(
-                project=project,
-                bucket=self.messages.Bucket(
-                    name=bucket,
-                    location=location,
-                )))
+        self.client.buckets.Insert(storage_buckets_insert_request)
       except api_exceptions.HttpConflictError:
         # We lost a race with another process creating the bucket. At least we
         # know the bucket exists. But we must check again whether the
@@ -374,6 +423,21 @@ class StorageClient(object):
         self.client.buckets.Get(self.messages.StorageBucketsGetRequest(
             bucket=bucket,
         ))
+      else:
+        # We just created the bucket ourselves; no need to check for ownership.
+        return
+
+    if not check_ownership:
+      return
+    # Check that the bucket is in the user's project to prevent bucket squatting
+    # exploit (see b/33046325, b/169171543).
+    bucket_list_req = self.messages.StorageBucketsListRequest(
+        project=project, prefix=bucket)
+    bucket_list = self.client.buckets.List(bucket_list_req)
+    if not any(b.id == bucket for b in bucket_list.items):
+      raise BucketInWrongProjectError(
+          'Unable to create bucket [{}] as it already exists in another '
+          'project.'.format(bucket))
 
   def GetBucketLocationForFile(self, object_path):
     """Returns the location of the bucket for a file.
