@@ -674,7 +674,7 @@ def AddResourceTypeSelectorFlag(parser, required=False):
   parser.add_argument(
       '--resource-type',
       help=(
-          'The resource type selector for key handles of the form'
+          'The resource type selector for KeyHandle resources of the form'
           ' {{SERVICE}}.{{UNIVERSE_DOMAIN}}/{{TYPE}}.'
       ),
       required=required,
@@ -687,11 +687,11 @@ def AddCreateKeyHandleFlags(parser):
   group = parser.add_group(mutex=True, required=True)
   group.add_argument(
       '--key-handle-id',
-      help='The key handle id for the new key handle.',
+      help='The KeyHandle id for the new KeyHandle resource.',
   )
   group.add_argument(
       '--generate-key-handle-id',
-      help='Generate a key handle id for the new key handle.',
+      help='Generate a KeyHandle id for the new KeyHandle resource.',
       action='store_true',
   )
 
@@ -699,7 +699,7 @@ def AddCreateKeyHandleFlags(parser):
 def AddFolderIdFlag(parser, required=False):
   parser.add_argument(
       '--folder',
-      help='The folder id in which the autokey config resource exists.',
+      help='The folder id in which the AutokeyConfig resource exists.',
       required=required,
   )
 
@@ -707,7 +707,7 @@ def AddFolderIdFlag(parser, required=False):
 def AddAutokeyConfigFileFlag(parser):
   parser.add_argument(
       'CONFIG_FILE',
-      help='The file containing the autokey config resource.',
+      help='The file containing the AutokeyConfig resource.',
   )
 
 
