@@ -46,9 +46,6 @@ class UpdateBackend(base.UpdateCommand):
   To add, remove, or swap backends, use the `gcloud compute backend-services
   remove-backend` and `gcloud compute backend-services add-backend` commands.
   """
-  # This fields decides whether --preference flag can be set when updating the
-  # backend.
-  support_preference = True
   support_custom_metrics = False
 
   @staticmethod
@@ -142,11 +139,7 @@ class UpdateBackend(base.UpdateCommand):
     if backend_to_update is not None and args.failover is not None:
       backend_to_update.failover = args.failover
 
-    if (
-        self.support_preference
-        and backend_to_update is not None
-        and args.preference is not None
-    ):
+    if backend_to_update is not None and args.preference is not None:
       backend_to_update.preference = (
           client.messages.Backend.PreferenceValueValuesEnum(args.preference)
       )
@@ -244,8 +237,6 @@ class UpdateBackendBeta(UpdateBackend):
   https://cloud.google.com/load-balancing/docs/backend-service.
   """
 
-  # Allow --preference flag to be set when updating the backend.
-  support_preference = True
   support_custom_metrics = True
 
   @classmethod
@@ -304,8 +295,6 @@ class UpdateBackendAlpha(UpdateBackendBeta):
   For more information about the available settings, see
   https://cloud.google.com/load-balancing/docs/backend-service.
   """
-  # Allow --preference flag to be set when updating the backend.
-  support_preference = True
   support_custom_metrics = True
 
   @classmethod
