@@ -126,10 +126,31 @@ def _CommonArgs(parser):
                                        'must provide a valid email address'),
       help='Default service account to run the workers as.')
 
+  parser.add_argument(
+      '--cloud-build-service-account',
+      type=arg_parsers.RegexpValidator(
+          r'.*@.*\..*', 'must provide a valid email address'
+      ),
+      help=(
+          'Service account to run the Cloud Build in the format'
+          ' projects/{project}/serviceAccounts/{service_account}. Ensure that'
+          " the account you are using to run 'gcloud dataflow flex-template"
+          " build' has 'ServiceAccountUser' role on the specified Cloud"
+          ' Build service account you provide with the'
+          ' --cloud-build-service-account flag. The specified service account'
+          ' must have required permissions to build the image. If the specified'
+          ' service account is in a project that is different from the project'
+          ' where you are starting builds, see'
+          ' https://cloud.google.com/build/docs/securing-builds/configure-user-specified-service-accounts#cross-project_set_up'
+          ' to grant the necessary access.'
+      ),
+  )
+
   parser.add_argument(
       '--max-workers',
       type=int,
-      help='Default maximum number of workers to run.')
+      help='Default maximum number of workers to run.',
+  )
 
   parser.add_argument(
       '--disable-public-ips',
@@ -251,15 +272,17 @@ def _CommonArgs(parser):
       '--flex-template-base-image',
       help=(
           'Flex template base image to be used while building the container'
-          ' image. Allowed choices are JAVA8, JAVA11, JAVA17 or gcr.io path of'
-          ' the specific version of the base image. For JAVA8, JAVA11 and'
-          ' JAVA17 option, we use the latest base image version to build the'
-          ' container. You can also provide a specific version from this link '
+          ' image. Allowed choices are JAVA8, JAVA11, JAVA17, JAVA21 or gcr.io'
+          ' path of the specific version of the base image. For JAVA8, JAVA11,'
+          ' JAVA17 and JAVA21 option, we use the latest base image version to'
+          ' build the container. You can also provide a specific version from'
+          ' this link '
           ' https://gcr.io/dataflow-templates-base/'
       ),
       type=arg_parsers.RegexpValidator(
-          r'^JAVA11$|^JAVA17$|^JAVA8$|^PYTHON3$|^GO$|^gcr.io/.*',
-          "Must be JAVA11, JAVA17, JAVA8, PYTHON3, GO, or begin with 'gcr.io/'",
+          r'^JAVA11$|^JAVA17$|^JAVA21$|^JAVA8$|^PYTHON3$|^GO$|^gcr.io/.*',
+          'Must be JAVA11, JAVA17, JAVA21, JAVA8, PYTHON3, GO, or begin with'
+          " 'gcr.io/'",
       ),
       required=True,
   )
@@ -314,12 +337,17 @@ def _CommonRun(args):
   image_path = args.image
   if not args.image:
     image_path = args.image_gcr_path
-    apis.Templates.BuildAndStoreFlexTemplateImage(args.image_gcr_path,
-                                                  args.flex_template_base_image,
-                                                  args.jar, args.py_path,
-                                                  args.go_binary_path, args.env,
-                                                  args.sdk_language,
-                                                  args.gcs_log_dir)
+    apis.Templates.BuildAndStoreFlexTemplateImage(
+        args.image_gcr_path,
+        args.flex_template_base_image,
+        args.jar,
+        args.py_path,
+        args.go_binary_path,
+        args.env,
+        args.sdk_language,
+        args.gcs_log_dir,
+        args.cloud_build_service_account,
+    )
 
   return apis.Templates.BuildAndStoreFlexTemplateFile(
       args.template_file_gcs_path, image_path, args.metadata_file,
@@ -328,6 +356,7 @@ def _CommonRun(args):
       args.image_repository_password_secret_id, args.image_repository_cert_path)
 
 
+@base.DefaultUniverseOnly
 @base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA)
 class Build(base.Command):
   """Builds a flex template file from the specified parameters."""
