@@ -20,15 +20,18 @@ from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.run import connection_context
+from googlecloudsdk.command_lib.run import exceptions
 from googlecloudsdk.command_lib.run import flags
 from googlecloudsdk.command_lib.run import resource_args
-from googlecloudsdk.command_lib.run import revision_printer
 from googlecloudsdk.command_lib.run import serverless_operations
+from googlecloudsdk.command_lib.run.printers import export_printer
+from googlecloudsdk.command_lib.run.printers import revision_printer
 from googlecloudsdk.command_lib.util.concepts import concept_parsers
 from googlecloudsdk.command_lib.util.concepts import presentation_specs
 from googlecloudsdk.core.resource import resource_printer
 
 
+@base.UniverseCompatible
 class Describe(base.DescribeCommand):
   """Obtain details about revisions."""
 
@@ -54,18 +57,20 @@ class Describe(base.DescribeCommand):
     concept_parsers.ConceptParser([
         revision_presentation]).AddToParser(parser)
 
+    resource_printer.RegisterFormatter(
+        revision_printer.REVISION_PRINTER_FORMAT,
+        revision_printer.RevisionPrinter, hidden=True)
+    parser.display_info.AddFormat(revision_printer.REVISION_PRINTER_FORMAT)
+    resource_printer.RegisterFormatter(
+        export_printer.EXPORT_PRINTER_FORMAT,
+        export_printer.ExportPrinter, hidden=True)
+
   @staticmethod
   def Args(parser):
     Describe.CommonArgs(parser)
 
   def Run(self, args):
     """Show details about a revision."""
-    # TODO(b/143898356) Begin code that should be in Args
-    resource_printer.RegisterFormatter(
-        revision_printer.REVISION_PRINTER_FORMAT,
-        revision_printer.RevisionPrinter)
-    args.GetDisplayInfo().AddFormat(revision_printer.REVISION_PRINTER_FORMAT)
-    # End code that should be in Args
     conn_context = connection_context.GetConnectionContext(
         args, flags.Product.RUN, self.ReleaseTrack())
     revision_ref = args.CONCEPTS.revision.Parse()
@@ -74,6 +79,6 @@ class Describe(base.DescribeCommand):
       wrapped_revision = client.GetRevision(revision_ref)
 
     if not wrapped_revision:
-      raise flags.ArgumentError(
-          'Cannot find revision [{}]'.format(revision_ref.revisionsId))
+      raise exceptions.ArgumentError('Cannot find revision [{}]'.format(
+          revision_ref.revisionsId))
     return wrapped_revision
