@@ -60,18 +60,17 @@ Container Flags
   group.AddArgument(flags.MemoryFlag())
   group.AddArgument(flags.CpuFlag())
   group.AddArgument(flags.ArgsFlag())
-  group.AddArgument(flags.SecretsFlags())
+  group.AddArgument(flags_parser.SecretsFlags())
+  group.AddArgument(flags.DependsOnFlag())
   group.AddArgument(flags.CommandFlag())
   # ALPHA features
   group.AddArgument(flags.AddVolumeMountFlag())
   group.AddArgument(flags.RemoveVolumeMountFlag())
   group.AddArgument(flags.ClearVolumeMountsFlag())
-  group.AddArgument(flags.GpuFlag())
 
   return group
 
 
-@base.Hidden
 @base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class Deploy(base.Command):
@@ -97,7 +96,7 @@ class Deploy(base.Command):
   def Args(cls, parser):
     flags.AddBinAuthzPolicyFlags(parser)
     flags.AddBinAuthzBreakglassFlag(parser)
-    flags.AddCloudSQLFlags(parser)
+    flags_parser.AddCloudSQLFlags(parser)
     flags.AddCmekKeyFlag(parser)
     flags.AddCmekKeyRevocationActionTypeFlag(parser)
     flags.AddDescriptionFlag(parser)
@@ -110,8 +109,8 @@ class Deploy(base.Command):
     flags.AddMaxUnavailableFlag(parser, resource_kind='worker')
     flags.AddScalingFlag(parser)
     flags.AddVolumesFlags(parser, cls.ReleaseTrack())
-    flags.AddGpuTypeFlag(parser)
     flags.AddVpcNetworkGroupFlagsForUpdate(parser, resource_kind='worker')
+    flags.RemoveContainersFlag().AddToParser(parser)
     flags.AddEgressSettingsFlag(parser)
     flags.SERVICE_MESH_FLAG.AddToParser(parser)
     flags.AddAsyncFlag(parser)
@@ -344,6 +343,7 @@ class Deploy(base.Command):
           build_from_source_container_name=container_name,
           repo_to_create=repo_to_create,
           already_activated_services=already_activated_services,
+          force_new_revision=True,
       )
       if not response:
         raise exceptions.ArgumentError(
